#
# First steps in R
#

library(quanteda)
library(readtext)
library(stopwords)
library(xlsx)

work.dir <- ("C:\\path\\to\\folder")

setwd(work.dir)

setwd(("C:\\Users\\Lukas\\Google Drive\\ceners\\Education\\MVEB\\Kurzy\\MEB421_Metody\\2020\\In-class scripts\\MEBn5021_11_ta2"))

#
# Reading texts into R
#

text.dir <- ("C:\\Users\\Lukas\\Google Drive\\ceners\\Education\\MVEB\\Kurzy\\MEB421_Metody\\2020\\In-class scripts\\MEBn5021_11_ta2\\texts_en")

texts <- readtext(file = text.dir,encoding = "UTF-8")

#
# Corpus
#

corp <- corpus(x = texts)

corp

ndoc(corp)

summary(corp)

#
# Tokenization
#

tokenization <- tokens(x = corp, 
                       what = "word",
                       ngrams= 1,
                       remove_numbers = TRUE, 
                       remove_punct = TRUE, 
                       remove_separators = TRUE, 
                       split_hyphens = FALSE
                       )



tokenization.bigrams <- tokens_ngrams(tokenization, n = 2)

sum(ntoken(tokenization))

sum(ntoken(tokenization.bigrams))

#
# Document-feature matrix
#

basic.matrix <- dfm(x = tokenization,
                    tolower = TRUE)

bigram.matrix <- dfm(x = tokenization.bigrams,
                    tolower = TRUE)

stem.matrix <- dfm(x = tokenization,
                     tolower = TRUE,
                     stem = TRUE)

prep.matrix <- dfm(x = tokenization,
                   tolower = TRUE,
                   stem = TRUE,
                   remove = stopwords(language = "en")
                   )

?stopwords

#
# DFM weighting
#

weight.matrix <- dfm_weight(prep.matrix,
                            scheme = "prop")

tfidf.matrix <- dfm_tfidf(prep.matrix)

#
# DFM manipulation
#
 
red.matrix <- dfm_trim(prep.matrix,
                       min_termfreq = 5)

basic.matrix
prep.matrix
red.matrix


sample.matrix <- dfm_sample(prep.matrix,
                            size = 5)

sample.matrix

#
# KWIC
#

kewords.in.context <- kwic(corp, 
                           pattern = "energy",
                           window = 5) 

kewords.in.context.2 <- kwic(corp, 
                             pattern = c("energy", "russia"),
                             window = 5) 

kewords.in.context

write.xlsx(kewords.in.context,"kwic.xlsx")

textplot_xray(
  kwic(corp, "security"),
  kwic(corp, "energy"),
  sort = T
) 

textplot_xray(
  kwic(corp,pattern=c("security"),window = 5),
  kwic(corp,pattern=c("energy"),window = 5),
  scale = "absolute",
  sort=T
)

#
# Frequencies
#

freq.basic <- textstat_frequency(x = basic.matrix, n = 20)


freq.stem <- textstat_frequency(x = stem.matrix, n = 20) 


freq.prep <- textstat_frequency(x = prep.matrix, n = 20) 

freq.prep

write.xlsx(freq.prep,"frequencies.xlsx")


#
# Wordcloud
#

textplot_wordcloud(x = basic.matrix,
                   max_words = 50,
                   min_size = 1,
                   max_size = 4,
                   rotation = 0,
                   color = "steelblue2")


textplot_wordcloud(x = prep.matrix,
                   max_words = 50,
                   min_size = 1,
                   max_size = 4,
                   rotation = 0,
                   color = "red3")


#
# Dictionaries
#

wordstat.dict <- dictionary(file = "LaverGarry.cat",
                            format = "wordstat")

dfm.dict <- dfm(tokenization,
                dictionary = wordstat.dict)

dfm.dict.w <- dfm_weight(dfm.dict,scheme = "prop")

dfm.dict.w

write.xlsx(dfm.dict.w,file = "dfm.dictionary.weighted.xlsx")